@@ -7,4 +7,4 @@ from brainchain.tools.graph import execute_cypher_query, graph_query
 from brainchain.tools.factual import fact_check
 from brainchain.tools.diffbot import diffbot_analyze
 from brainchain.tools.plan import generate_plan, improve_plan, execute_plan
-from brainchain.tools import functions
\ No newline at end of file
+from brainchain.tools import tool_schemas
\ No newline at end of file
