@@ -1,4 +1,4 @@
-def tool_schemas():
+def tool_schemas(openai: bool = True, anthropic: bool = False):
     functions_ = [ {
             "type": "function",
             "name": "diffbot_analyze",
@@ -470,4 +470,19 @@ def tool_schemas():
       }
     }
     ]
-    return functions_
+
+    if anthropic:
+        new_out = []
+        for item in functions_:
+            new_item = {}
+            for k in item:
+                if k == "parameters":
+                    new_item["input_schema"] = item[k]
+                elif k == "type" or k == "returns":
+                    pass
+                else:
+                    new_item[k] = item[k]
+            new_out.append(new_item)
+        return new_out
+    if openai:    
+        return functions_
